---
layout: assignment
published: true

title: Website/App Accessibility UARS (Individual)
description: Learn to assess website/app accessibility using a variety of technologies
code: hw2

assigned: Jan 10, 2023
due: 
   - UARS--Due before class on 1/17
   - No grace period--These will be discussed in class
   
revised: April 11, 2023

---
* TOC
{: toc}

# Overview
The goal of this homework is to learn about basics of website accessibility and how to assess. In part 1, you: Learn how to use automated tools (and their limitations); Learn how to address the limitations of automated tools using accessibility tools; In part 2, you: Learn how to write up an assessment and prioritize what problems to fix; Practice identifying paths to fixing problems. You will also have the opportunity to practice UI image description. 

## Competencies
This homework may contribute to your competency grade on 
- Can apply web/app accessibility rules to identify problems, including
  - 1 whether content is perceivable
  - 2 whether content is operable 
  - 3 whether content is understandable
  - 4 whether content is robust
  <!-- - 5 the meaning of conformance -->
- Can use an accessibility checker to assess whether a web page or app is accessible
- Can use an accessibility technology to find web page or app accessibility problems that are not found with an automated accessibility checker
- Can articulate paths to addressing accessibility problems
- Accessible written document creation
- Image description
- Your participation grade, as a percentage of completeness (are all the required parts present)

## Length & Difficulty
Students in the past have reported that taken together, part 1 and part 2 of this assignment require a median of 20 hours (mode=6). A challenge that multiple students faced is summarizing the WCAG guidelines in their own words. Please be sure to do so, *or* to quote and reference WCAG guidelines according to our [course policy on academic conduct]({{site.baseurl}}/academic-conduct.html). Some things that students have told us about this assignment:
- It helps to use the [UAR template](webegs/UAR_Template.doc) when filling out the UARS.
- It was very motivating to do this for a real client

# Details
Your goal is to generate a range of UARs documenting accessibility concerns (and perhaps successes) with a website or app. You will use [W3C guidelines](https://www.w3.org/WAI/standards-guidelines/) for the site or app you are assessing. 

The most relevant are probably [WCAG
2.1](https://www.w3.org/WAI/standards-guidelines/wcag/glance/) and
[How WCAG 2.0 Applies to
Mobile](https://www.w3.org/TR/mobile-accessibility-mapping/) (even
websites may be used in mobile settings). If you are working on a
mobile app, you should also review this PDF (which is numbered page
9): [Epidemiology as a Framework for Large-Scale Mobile Application
Accessibility
Assessment](https://xiaoyizhang.me/assets/Paper/ASSETS_2017_Epidemiology.pdf).

## 0. Pick a website and/or app and two tasks 
You may submit your top three choices for website/app from listing below and include at most one of your own on the [Discussion thread for selection]({{site.discussion}}) for this assignment. Our goal is to have *at least four students** working independently on each website. Note that there is a *task* associated with each website/app (and if you pick your own, you should also have a task in mind).  

{% details Possible websites/apps %}
In the past, website have been sponsored by CREATE partners and community members. Student reports have been received by them with great gratitude, generating comments such as "This is fantastic" and "What an amazing and helpful report!" with plans to implement the recommendatinos. 

- [VolunteerMeet Techies For Reproductive Justice](https://ddf.volunteermeet.org/): VolunteerMeet is a tool for abortion access and reproductive justice groups to use to recruit and vet volunteers. VolunteerMeet is used by several large organizations, and we want to make sure we are not limiting the participation of people with disabilities. **Focus**: The application process. 
- [Digital Defense Fund](https://digitaldefensefund.org/): Our website has a large amount of (free!) material about how to access abortion and other reproductive health care safely in today's criminalized environment. We have resources about digital security, staying safe online, and tech-enabled advocacy, among many other topics - all of which are incredibly important to all of us, but perhaps especially to people may be more vulnerable to surveillance because of their disabilities. **Focus**: Two sections of our site in particular: Learn & Media 
- [PAVE](https://wapave.org/): With our goal of continual improvement, we would like to always test the website periodically to make sure we are making sure it is accessible to everyone.  **Focus**: Accessibility and ease of use
- [CREATE](https://create.uw.edu/): CREATE's website should already be pretty accessible, but we haven't had any outside testers look at it. Help us find th egaps and problems! **Focus**: Finding out about funding
- Other: We are happy to take submissions for other websites that you might want to focus on. If you do this, you must recruit *at least one* other student in the class (preferably three others) who will (independently) look at the same website
{% enddetails %}


## 1. Collect Data on  accessibility problems using an automated accessibility checker
For each of these steps, you will record data about what you find so that you can complete the write up at the end.

You should run the website and/or app through an accessibility checker. The WebAim accessibility checker, [WAVE](https://wave.webaim.org/), is a great choice for many sites. However, if the site requires that you log in, you may need an alternative. A great choice is the [Chrome plugin Axe](https://chrome.google.com/webstore/detail/axe-devtools-web-accessib/lhdoppojpmngadmnindnejefpokejbdd?hl=en-US). 

To install the Accessibility Scanner on android, search for it in the
Play Store and install it on your device or emulator. The installation
process will be the same for a physical phone or the emulator equipped
with the Play Store. Follow the instructions on the [Getting started
with Google Accessibility
Scanner](https://support.google.com/accessibility/android/answer/6376570?hl=en&ref_topic=6376582)
page to get the scanner working on your device. Another option is to install the Android Accessibility Suite which contains both the Accessibility Scanner and TalkBack if it has not been installed before.

For iOS, you should install the Accessibility Inspector, which is freely available through the App Store. More details on [testing for accessibility in iOS.](https://developer.apple.com/library/archive/documentation/Accessibility/Conceptual/AccessibilityMacOSX/OSXAXTestingApps.html)

## 2. Collect Date on accessibility problemsusing TWO DIFFERENT accessibility technologies
Use *multiple approaches*, including at a minimum  **a screen reader** and **magnification** to assess the website
and/or app, and your ability to complete the assigned task using
accessibility tools. You may also use other accessibility tools if you
feel there are things that does not address, such as speech based input, or switch input.

Here are some resources that may help you in gaining comfort with these accessibility technologies 
- [Zoomtext and other magnification in use](https://www.youtube.com/watch?v=4ZRVDgeMpXc) and [Setting up windows for zooming](https://www.youtube.com/watch?v=TQhUCnMhDZE)
- [Screen reading intro](https://axesslab.com/what-is-a-screen-reader/)
- Switch control intro: [Switch Control overview](https://www.youtube.com/watch?v=GQKEE9nI1lk)
- Advanced voice based input: [voice programming](https://www.youtube.com/watch?v=YKuRkGkf5HU)

## 3.  Record the data in a *Usability Aspect Report*
Record each group of similar issues you find using this [Usability Aspect Report Template](webegs/UAR_Template.doc). Here is a [sample](webegs/DDUARS.docx) that a prior student has kindly shared with us for you to look at. Make sure that your UARs are accessible

Some key things to make note of: 
- **Good or Bad Feature** *If your website as very accessible* you may include UARS for particularly good features 
- **Source** including *your initials*; *the type of AT used*; and a unique ID such as JM-SR-3 (which means, approximately, Jennifer Mankoff Screen Reader UAR # 3)
- **Name/Brief Description** Provide a very brief name/summary
- **Evidence** Specify the guideline violated and provide a screen shot with ALT text or other evidenc. 
- **Explanation** Explain why this is a problem (or good aspect.
- **Severity** Rank severity (with 4 being catastrophe) 
- **Justification** Justify your ranking in terms of *frequency* *impact* and *persistence*
- **Relationship to other problems** If this is related to/caused by/causes other problems you record, you can give their *source* number here

# Turnin

Submit your UARS as an attachment to the appropriate  [discussion]({{site.discussion}})



