---
layout: default
title: Schedule
description: Class schedule and links to lectures, readings and assignments
---

* TOC
{:toc}

{: .module} # Module 1: Accessibility Basics 
: 

{: .week}
# Week 1 (1/3): Introduction to Accessibility

{% details Learning Goals %} 
- What is Accessibility? Disability?
- What is the difference between Disability studies, Disability Justice; and various models of disability
- History of disability rights 
- Understand models for disability-centered design
{% enddetails %}

{% details Class Plan %} 

{: .topic}  5:30-6:20 Introduction to Accessibility & Disability
: **Slides** {% include slide.html title="Introduction to Accessibility" loc="accessibility.html" %}

{: .break}  6:20-6:40 
: Break / Food 


{: .topic} 6:40-7:50 In-class Activities 
: **Slides** {% include slide.html title="In Class Activities" loc="accessibility-activities.html" %}

{: .activity} Skill Goal: Learn how accommodations can make a meeting more inclusive
: **In class Exercise** Put your accommodation needs into PollEverywhere; discuss what comes up and what else might be relevant 
: **Small Group Discussion** How would you implement this in your workplace? ([post on Ed](https://edstem.org/us/courses/31170/discussion/2347303))

{: .activity} Skill Goal: Analyze a piece of technology from a Disability Rights perspective
: **Small Group Discussion** Analysis of the iPhone ([post on Ed](https://edstem.org/us/courses/31170/discussion/2342976))

{: .activity} Skill Goal: Analyze a topic from a disability justice perspective
: **Small Group Discussion** Analyze masking from a disability justice perspective ([post on Ed](https://edstem.org/us/courses/31170/discussion/2345037))

{: .break} 7:50-8:00
: Break 

{: .topic}  8:00-8:20 Overview of course 
: **Slides** {% include slide.html title="Introduction to Course" loc="syllabus.html" %}
Introduction to course syllabus & assignments

{% enddetails %}


{% details Preparation for next week  %}
{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} [Disability Justice Homework](assignments/disabilityjustice.html) Assigned: Pick an access topic and analyze it from a disability justice perspective.
: 

{: .homework} Readings for next week 
: 
- **Required: Reading AND Preparation** by start of class. Respond to the reading questions by  start of class and Preparation requirements on Ed. 
   - **Come to next class prepared** to use either switch control, a screen reader, or magnification on your phone. 
   - Accessibility Testing: Read [The importance of Manual Accessibility Testing](https://www.smashingmagazine.com/2018/09/importance-manual-accessibility-testing/) and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2345222)
   - **Come to next class prepared** with an image you found on the web that does not have ALT text
   - ALT text: Read about [creating accessible images and diagroms](https://dis.acm.org/2023/creating-accessible-figures-and-tables/) and watch [It's complicated](https://www.youtube.com/watch?v=By6nzFefcxs) and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2345223)
   - Audio Description: Read [What is audio description?](https://adp.acb.org/articles/adprocess.html) from [The Audio Description Project](https://www.acb.org/adp/ad.html) and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2345225)
- **Optional**
   - [Switches](https://axesslab.com/switches/)
   - [Image ALT Text Tutorial](https://webaim.org/techniques/alttext/) 
{% enddetails %}

{: .week}
# Week 2 (1/10): Accessibility Assessment 1: Guidelines and Assessment

{: .prepare} Come Prepared
: Come to class with an image, diagram, or other graphic you want to describe; Be prepared (install and try out) one of: switch control, a screen  reader, or magnification on your phone

{% details Learning Goals %} 
- What are the current accessibility standards
- Get comfortable with basic image  description (images, people)
- How do we use automated tools to assess accessibility
- How can we use accessibility technology to assess accessibility
- Get comfortable using existing freely available accessibility technology to support assessment
{% enddetails %}

{% details Class Plan %} 

{: .topic}  5:30-6:00 Introduction to Assessing Accessibility  & Practice
: **Slides** {% include slide.html title="Assessing Accessibility" loc="assessment.html" %}

{: .activity} Skill Goal: Image Description 
: **In class Exercise**  Break into small groups and show each other the inaccessible images you found. Work on a short and long description appropriate to your image type. ([post on Ed](https://edstem.org/us/courses/31170/discussion/2347293))

{: .break}  6:20-6:40 
: Break / Food 

{: .topic} 6:40-7:40 More about Assessment
: Digging deeper into assignments and assessment skills

{: .topic}  Guidelines 1.1, 1.2, and Automated Assessment
: **Slides Continue** {% include slide.html title="Assessing Accessibility Cont..." loc="assessment.html#45" %}

{: .activity} Skill Goal: Automated Assessment 
: **In class Exercise** Use WebAIM [Wave](https://wave.webaim.org/) to [assess the Seattle Public Schools Website](https://wave.webaim.org/report#/https://www.seattleschools.org/) ([Post a UAR on Ed](https://edstem.org/us/courses/31170/discussion/2349808)

{: .break} 7:40-7:50
: Break 

{: .topic}  Guidelines 1.3, 1.4, and Manual Assessment
: **Slides Continue** {% include slide.html title="Assessing Accessibility Cont..." loc="assessment.html#52" %}

{: .activity} Skill Goal: Use Accessibility Technologies to assess the same website
: **Slides** {% include slide.html title="Assessing Accessibility Cont..." loc="assessment.html#65" %}

**In class Exercise** Break into small groups. Each pick one of the following and try out the website
- Screen reader
- Switch input
- Magnification

Try to find something you didn't find with an automated tool. ([Post a UAR on Ed](https://edstem.org/us/courses/31170/discussion/2349808))

{% enddetails %}
 

{% details Preparation for next week  %}
{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} [Website/app accessibility](assignments/website.html) Assigned: Assess and write a report
: 

{: .homework} Readings for next week 
: 

- **Required Readings:** Respond to the Reading Questions and Preparation Requirements on Ed
   - Read: [Comparison of different methods for accessibility testing](https://sol.sbc.org.br/journals/index.php/jis/article/view/1778/1848) Mateus etal, 2021  and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2363730) 
   - Read: About how [web semantics are conveyed to screen readers](https://alistapart.com/article/semantics-to-screen-readers/)   and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2363732) 
   - Read: [Accessibility in Software Practice: A Practitioner’s Perspective](https://dl.acm.org/doi/abs/10.1145/3503508) and Respond on Ed (TBD)
- **If you want to dig deeper**
   - Watch: [Google Video on Practical Web Accessibility](https://www.youtube.com/watch?v=x18vEEfpK3g) — this video provides a great overview of the Web and how to make web content accessible. Highly recommended as a supplement to what we will cover in class.
   - Watch: [Latte: Use-Case and Assistive-Service Driven Automated Accessibility Testing Framework for Android](https://www.youtube.com/watch?v=Z84jeO0UZFE) and read [Lies, Damned Lies, Overlays, and Widgets](https://www.linkedin.com/pulse/lies-damned-overlays-widgets-timothy-springer/)
   - Read: [Semantics for Eye tracking](https://dl.acm.org/doi/pdf/10.1145/3338844)
   - Watch: [Rescribe: Authoring and Automatically Editing Audio Descriptions](https://www.youtube.com/watch?v=jmyPmT5T0PY)
   - Read: [Is your web page accessible? A comparative study of methods for assessing web page accessibility for the blind](https://dl.acm.org/doi/10.1145/1054972.1054979)

{% enddetails %}

{: .week}
# Week 3 (1/17): Accessibility Assessment 2: Tradeoffs and Advanced Methods
{% details Learning Goals %} 
- What are the tradeoffs between different tools?
- Beginning to look at study design by example
- More advanced accessibility techniques
    - Differences between Image description, Diagram description and UI description
    - Video description & Captioning
    - Math, Tables & other elements (including custom interactors)
    - Navigation and its impact on Accessibility; how to set up proper header structures.
{% enddetails %}

{% details Class Plan %} 

{: .topic}  5:30-6:00 Comparison of Accessibility Assessment Approaches
: **Slides** {% include slide.html title="Assessing Accessibility: Comparing Techniques" loc="assessment2.html" %}

{: .activity} Discussion: Value of Cumulative Assessment
: **In class Exercise**  Find the students who assessed the same website as you. Talk about the UARs you generated. Did you find different problems from other students? Why do you think you did, or did not, find different problems? Post your discussion notes to the Ed Thread for your website.

{: .break}  6:20-6:40 
: Break / Food 

{: .topic}  6:40-7:40 Best Practices for Improving Accessibility
: **Slides** {% include slide.html title="Best Practices: Improving Accessibility" loc="best-practices.html" %}

{: .activity} Skill Goal: Video description
: **In class Exercise** Break into small groups. Pick a video from [youdescribe.org](https://youdescribe.org/) and work on a description as a group. ([post a link to your video on Ed](https://edstem.org/us/courses/31170/discussion/2350670))


{: .break} 7:40-7:50
: Break 

{: .activity} In Class Work Time
: Finish your video description and post it. If done early, work on your website writeup.


{% enddetails %}

{% details Preparation for next week  %}
{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} Readings for next week 
: 

- **Required Readings** Respond to the Reading Questions and Preparation Requirements on Ed
    - Read [Anticipate and Adjust](https://dl.acm.org/doi/abs/10.1145/3491102.3501882) [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2364596) 
	- Read [How Alexa can change the life of a disabled person](https://abilitynet.org.uk/news-blogs/how-alexa-can-change-life-disabled-person) [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2364598)
    - Read [Disability Dongles](https://blog.castac.org/2022/04/disability-dongle/) by Liz Jackson and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2364600) 
- **If you want to dig deeper**
   - [How To Do Something Good In The Disability Community If You’re Not Disabled](https://www.forbes.com/sites/andrewpulrang/2020/12/16/how-to-do-something-good-in-the-disability-community-if-youre-not-disabled/?sh=4befcb377d7f)
   - [COVID 19 websites violate disability laws](https://www.latimes.com/california/story/2021-02-25/covid-19-vaccine-websites-violate-disability-laws-create-inequity-for-the-blind)
   - [Alexa & Accessibility](https://dl.acm.org/doi/pdf/10.1145/3173574.3174033?casa_token=T1I2RwihIjsAAAAA:QEm3SjurdlcW7oX_1LadxaglZ7oneBX-XLIjMCHbof3gu_IFpDW2OO5tqxZfLIps-94Qik9y5wNw8Q) 
   - [Design, Disability and Knowing the 'Other'](https://dl.acm.org/doi/fullHtml/10.1145/3290605.3300528#:~:text=WHAT%20IS%20EMPATHY%3F-,The%20Promise%20of%20Empathy%3A%20Design%2C%20Disability,%2C%20and%20Knowing%20the%20'Other'&text=This%20paper%20examines%20the%20promise,order%20to%20inform%20technology%20development.)  

{% enddetails %}

{: .week}
# Week 4 (1/24): Accessible Needfinding and Evaluation
{% details Learning Goals %} 
- How to present accessibly
- How to write using plain language
- How to assess whether a technology is accessible; and whether an accessibility technology is useful and usable, in an inclusive fashion.
- How do you make sure your *product is accessible* to people with disabilities
   1. Data Equity and implicit bias
   2. Beyond automated assessment: Accessible Summative Studies
   3. Importance of Intersectionality
- How do you make sure your *accessibility technology is valued* by people with disabilities
   - What are potential data sources for assessing value
   - Collaboration Versus Paternalism
   - Overly narrow views of disability: Multiple disabled people & multiply disabled people
{% enddetails %}

{% details Class Plan %} 

{: .topic}  5:30-6:15 Introduction to Accessible Evaluation 
: **Slides** {% include slide.html title="Presenting Accessibly" loc="presenting-acessibly.html" %}
**Slides** {% include slide.html title="Assessing Accessibility" loc="evaluation.html" %}

{: .topic}  6:15-6:25 Practice Study Design
: **Amazon Alexa** 
    1. Write down a list of accessibility assessment goals (metrics) 
    2. Write down a sampling goal (who is included)
    3. Discuss

{: .break}  6:25-6:40 
: Break / Food 

{: .topic}  6:30-7:30 Slides & Discussion:
: **Slides** {% include slide.html title="Designing for and with people with disabilities" loc="designing.html" %}
**Slides** {% include slide.html title="Plain Language" loc="plain-language.html" %}

Discussion of Disability Dongle Paper

{: .topic}  7:30-7:40 First Person Accounts
: Introduction to  [Finding Accessibility](assignments/finding-accessibility.html)

{: .break} 7:40-7:50
{: .topic} 7:50-8:20 Work on Assignment 
: 

{% enddetails %}

{% details Preparation for next week %}
{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} [Finding Accessibility](assignments/finding-accessibility.html) Assigned: Summarize a first person account of an access technology
: 

{: .homework} [Plain Language](assignments/plain-language.html) Assigned: Write something up in plain language. 
: 

{: .homework} **Post-module Reflection:**  [Accessibility Basics Reflection](https://forms.gle/Wk8C51m5Sbq8RX7W8)
: 

{: .homework} Readings for next week 
: 

- **Required Readings** Respond  to the Reading Questions and Preparation Requirements on Ed
    - Read [Fairness issues in AI Systems that augment sensory abilities](https://arxiv.org/pdf/1908.07333.pdf) and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2424082) 
   - Read [A systematic literature review of handheld augmented reality solutions for people with disabilities](https://www.mdpi.com/1424-8220/22/20/7719) and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2436103)
    - Read [7 benefits of AR and VR for People with Disabilities](https://arpost.co/2022/02/09/7-benefits-ar-vr-for-people-with-disability/) and [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2423831) 
{% enddetails %}

{: .module} # Module 2: Second Wave Accessibility
: 

{: .week}
# Week 5 (1/31): AT Around us Presentations + AR/VR
{% details Learning Goals %} 

<!-- What are the accessibility concerns when groups of people use online technologies together for communication? -->

<!-- - Video conferencing  -->
<!-- - Large gatherings (virtual or hybrid) -->
<!-- - Online text based support groups -->
<!-- - Social networks such as twitter or facebook -->

<!-- What are the accessibility opportunities in online networks (e.g. crowdsourcing ) -->

{% enddetails %}


{% details Class Plan: %} 

{: .topic 5:30-7:00} Presentations
: Accessibility Assessment Assignment

{: .break}  7:00-7:10 
: Break / Food 

{: .topic 5:30-7:00} AR/VR 
: **Slides** {% include slide.html title="AR/VR" loc="arvr.html" %}
: try out Jon's tool hopefully

{% enddetails %}


{% details Preparation for next week  %}
{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
{: .homework} Readings for next week 
: 

- **Required: Respond to the Reading Questions and Preparation Requirements on Ed**

  - [Increasing Data Equity in Accessibility](https://arxiv.org/abs/2210.01902) No ed post for this one :)
  - [Understanding Screen-Reader Users’ Experiences with Online Data Visualizations](https://athersharif.me/documents/assets-2021-understanding-sru-experiences-online-data-viz.pdf) [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2485584)
  - [Data Representation in Accessibility Data Sets: A Meta-analysis](https://arxiv.org/abs/2207.08037) [**Respond on Ed**](https://edstem.org/us/courses/31170/discussion/2485589)

- **Optional**
  - [Areas of Strategic Visibility: Disability Bias in Biometrics](https://arxiv.org/abs/2208.04712)
  - [The Future of Urban Accessibility for People with Disabilities: Data Collection, Analytic, Policy, and Tools](https://dl.acm.org/doi/fullHtml/10.1145/3517428.3550402)
  - [Explaining Explanations: An Approach to Evaluating Interpretability of Machine Learning](https://www.cs.purdue.edu/homes/bb/nit/Lalana-Explainations%20of%20IAS.pdf)
  - [Rich Screen Reader Experiences for Accessible Data Visualization](https://arxiv.org/pdf/2205.04917.pdf)
  - [VoxLens: Making Online Data Visualizations Accessible With an Interactive JavaScript Plug-In](https://athersharif.me/documents/chi-2022-voxlens.pdf)

{% enddetails %}

{: .week}
# Week 6 (2/7): Data Equity
{% details Learning Goals %} 
- Bias in Machine Learning
    - What is Machine Learning (ML)? 
    - What are the components of ML?
    - How do we collect data? Who do we collect the data from?
    - Is the data "good"?
    - How do we minimize disability bias?
- Accessible Data Visualizations
    - What are the commonly-used techniques to make data visualizations accessible?
    - What are the pros and cons of these techniques?
    - What are some of the nuances in making data visualizations accessible?
{% enddetails %}

{% details Class Plan %} 

{: .topic}  5:35-6:20 Bias in Machine Learning
: **Slides** {% include slide.html title="Bias in Machine Learning" loc="bias-in-machine-learning.html" %}

{: .break}  6:20-6:30 Break / Food 
: 

{: .topic}  6:30-7:20 Accessible Data Visualizations
: **Slides** {% include slide.html title="Accessible Data Visualizations" loc="accessible-data-viz.html" %}


{: .break} 7:20-7:30 Break 
: 

{: .activity} 7:30-8:20 Discussion with Guest: 
: Matthew Butler

{% enddetails %}

{% details Preparation for next week  %}

{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} [Final Project](assignments/project.html) presentation preparation
: 

{% enddetails %}

{: .week}
# Week 7 (2/14): Final Project Proposals


{% details Preparation for next week  %}

{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} Readings for next week 
: 

- **Required: Respond to the Reading Questions and Preparation Requirements on Ed**
  - [Consumer-Grade Fabrication and Its Potential to Revolutionize Accessibility](https://dl.acm.org/doi/10.1145/3339824), CACM 2019

{% enddetails %}

{: .week}
# Week 8 (2/21): Making Accessibility: Fabrication and Physical Computing

{% details Class Plan: STILL TBD %} 

{: .topic 5:30-7:00} Fabrication and Accessibility
: **Slides** {% include slide.html title="Introduction to 3D Printing and Physical Computing" loc="3dprinting.html" %}


In-class exercise: Creating a laser cut accessibility aid. Steps are:
1. Create an SVG (can use powerpoint for this; will demonstrate) & make sure it has an *appropriate size in mm*
2. Print it on paper and cut it out to double check
3. Provide it to Jen for laser cutting 
4. Sand and/or assemble your object

{% details Example Objects %}
Some examples of things that one can laser cut which serve an accessibility purpose 
- a cookbook, or book, stand (https://bookriot.com/accessories-for-accessible-reading/)
- A pillbox  https://www.etsy.com/listing/1318967359/wooden-pill-box-pill-case-pill-organizer; make with https://www.festi.info/boxes.py/
- A one handed cutting board https://smile.amazon.com/Parsons-ADL-61-0200-Cutting-Board/ 

I'm also thinking about having them use fusion360 or something else to make something a little more shapely (I'm assuming these are all out of scope for you, but please correct me if I'm wrong)
- a jar opener https://www.thingiverse.com/thing:40131; https://www.thingiverse.com/thing:2801157
- keyboard tray tilters https://www.amazon.com/SUPBEE-Universal-Computer-Keyboard-Ventilated
- neck mounted cup holder https://www.thingiverse.com/thing:1863196 or possibly a laser cut one https://www.dxfdownloads.com/cup-holder-laser-wood/
- ipad keyguard: https://www.thingiverse.com/thing:1365497
- key handle https://www.thingiverse.com/thing:2802082
- https://www.instructables.com/Making-a-laser-cut-bag-holder/
- something to hold a book open (https://www.etsy.com/listing/883330413/book-buddy-book-holder-wood-thumb-page)
- phidget spinners https://www.instructables.com/Laser-Cut-MDF-Fidget-Spinner/
{% enddetails %}

{% enddetails %}

{% details Preparation for next week  %}

{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{: .homework} [Finding Accessibility](assignments/finding-accessibility.html) Assigned: Summarize a first person account of an access technology
: 

{: .homework} **Post-module Reflection:**  2nd Wave Accessibility Reflection (TBD)
: 

{% enddetails %}

{: .module} # Module 3: Third Wave Accessibility
: 

{: .week}
# Week 9 (2/28): Intersectionality with Race, Gender & Other Identities
{% details Learning Goals: STILL TBD %} 
{% enddetails %}

{% details Class Plan: STILL TBD %} 
...

{% enddetails %}


{% details Preparation for next week  %}

{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{% enddetails %}

{: .week}
# Week 10 (3/7): Sustainability, Urban Access and Housing
{% details Learning Goals: STILL TBD %} 
{% enddetails %}

{% details Class Plan: STILL TBD %} 
...

{% enddetails %}


{% details Preparation for next week  %}

{: .homework} [Class Participation survey](https://forms.gle/qcjc5fSNSAVeE5pK9)
: 

{% enddetails %}


<!-- {: .week} -->
<!-- # Week 10 (3/7):  Healthcare Technologies & Reproductive Justice -->


{: .week}
# Finals week: Final presentations 3/14, 6:30pm

{: .lecture} Final project presentations
: 

{% details Currently Unused %} 
**Optional**
- [Living Disability Theory: Reflections on Research, Access and Design](https://make4all.org/wp-content/uploads/2020/09/hoffmann-living-disability-theory.pdf)
- [Disability Studies as a source of critical inquiry...](https://make4all.org/wp-content/uploads/2019/10/MankoffAssets2010.pdf)
- [Vital coronavirus is failing the blind and visually impaired](https://www.vice.com/en/article/4ag9wb/vital-coronavirus-information-is-failing-the-blind-and-visually-impaired)
94Qik9y5wNw8Q) 
   - [Blurring the Boundaries Between Assistive Tech and Companionship](https://www.forbes.com/sites/gusalexiou/2021/01/26/amazon-alexa---blurring-the-boundaries-between-assistive-tech-and-companionship/?sh=2821499375e7) (a little too salesy)
{% enddetails %}
